Method: Statsd#batch
- Defined in:
- lib/statsd.rb
#batch {|Batch| ... } ⇒ Object
Creates and yields a Batch that can be used to batch instrument reports into larger packets. Batches are sent either when the packet is “full” (defined by batch_size), or when the block completes, whichever is the sooner.
442 443 444 |
# File 'lib/statsd.rb', line 442 def batch(&block) Batch.new(self).easy(&block) end |